package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````#AP```````!``````````#"A````
M`````````$``.``(`$``&``7``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````9`````````!D``````````0`````````!````
M!0````````````````````````````````````22````````!)(`````````
M`"````````$````&````")P````````(G"````````B<(```````6`0`````
M````%0``````````(````````@````8```!8G````````%B<(```````6)P@
M``````!P`0```````'`!````````"`````````!0Y71D!````,R,````````
MS(P```````#,C````````,P`````````S``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````(G`````````B<(```````")P@``````#X`P``````
M`/@#`````````0`````````O;&EB+VQD+6UU<VPM>#@V7S8T+G-O+C$`````
M`````!$```!$````!`````@````@#```!4`$@B@`4`"0A@"`@B$`($D"!`FX
M@AA)N@0&"D0```!%````20```$T```!.````5````%4```!7`````````%L`
M````````7````%X```!?````8```````````````H^D9!&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;_+;TQWB1\8!
MN^.2?%7#/-+$N9Q`9Z_,9CCRBQS$B060B`=PTT-%U>PS8MOM5J2;EJ?=HVM_
MJ9R;X:<""@J*$%>CX/M)``````````````````````````````````````P`
M```2`````````````````````````,X!```2````````````````````````
M`'`!```2`````````````````````````!L````2````````````````````
M`````*T!```2`````````````````````````",````2````````````````
M`````````"H````2``````````````````````````$"```2````````````
M`````````````+D!```2`````````````````````````#,````@````````
M`````````````````$L````2`````````````````````````%$````2````
M`````````````````````%@````2`````````````````````````!`#```2
M``````````````````````````$#```2`````````````````````````(8"
M```2`````````````````````````%\````2````````````````````````
M`"<"```2`````````````````````````&8````2````````````````````
M`````+L"```2`````````````````````````&T````2````````````````
M`````````'4````@`````````````````````````(D````2````````````
M`````````````*0"```2`````````````````````````)$````2````````
M`````````````````)<````2`````````````````````````*`````@````
M`````````````````````/H"```2`````````````````````````+P````2
M`````````````````````````,$````2`````````````````````````,("
M```2`````````````````````````%0"```2````````````````````````
M`"`#```2`````````````````````````$8"```2````````````````````
M`````*0#```2`````````````````````````'@"```2````````````````
M`````````#8#```2`````````````````````````,@````2````````````
M`````````````"X#```2`````````````````````````'X!```2````````
M`````````````````-$````B`````````````````````````.`````@````
M`````````````````````/8````2`````````````````````````/("```2
M`````````````````````````&0"```2`````````````````````````/L`
M```2``````````````````````````$!```@````````````````````````
M`*\"```2`````````````````````````!L!```2````````````````````
M`````)X!```2`````````````````````````"`!```2````````````````
M`````````)0"```2`````````````````````````(T!```2````````````
M`````````````"8!```2`````````````````````````#<!```2````````
M`````````````````"("```2`````````````````````````)(````2````
M`````````````````````#,"```2`````````````````````````&T"```2
M`````````````````````````"<#```2`````````````````````````#T!
M```2`````````````````````````!@#```2````````````````````````
M`%$!```2`````````````````````````!T"```2````````````````````
M`````-P!```2`````````````````````````%@!```2````````````````
M`````````&D!```2`````````````````````````$@#```A`!4`:*`@````
M```(`````````$,#```2``D`.!H```````#6`0```````.X!```2``H`G4T`
M```````!`````````.8#```2``D`$4````````#+"0```````%P$```2``D`
M)TT```````!1`````````,,#```2``D`[CH````````%`````````/4#```2
M``8`*!@````````!``````````D$```2``D`W$D```````!+`P```````$\$
M```2``D`\SH```````#``0```````%H#```0`!4`8*`@````````````````
M`-0#```2``D`>S\```````"6`````````/,#```2``D`@#D````````M````
M`````/L#```2``D`%#\```````!(`````````,T"```1`!$`0)P@```````3
M`````````"D$```2``D`LSP````````;`````````&8#```0`!4`"+$@````
M`````````````(D#```2``D`)!P````````H`````````$D#```1`!4`:*`@
M```````(`````````#8$```2``D`SCP```````"B`````````!0````1`!$`
M,)P@```````(`````````$H#```A`!4`:*`@```````(`````````!\$```1
M`!0`6*`@```````(`````````%,#```0`!0`8*`@`````````````````%\#
M```0``D`#AP``````````````````!("```1`!4`<*`@```````$````````
M`$L#```A`!4`:*`@```````(`````````)(#```2``D`7#\````````?````
M`````*T#```2``D`\SD```````#[`````````/0!```1`!4`8*`@```````!
M`````````$($```2``D`<#T```````"D`0````````!L:6)P97)L+G-O`&]P
M96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I
M<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N
M;&EN:P!M96UM;W9E`%]*=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A
M=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S
M=')S='(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M
M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R
M96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S
M<&5C:69I8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F,N;75S;"UX.#9?-C0N<V\N,0!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T
M9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?
M;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T
M`%]E;F0`+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A;G5P`+B>(```````"```
M```````H&`````````"@(```````"```````````H"```````""@(```````
M"`````````"*3@```````"B@(```````"`````````"#3@```````#"@(```
M````"`````````#$3P```````#B@(```````"`````````"@3@```````$"@
M(```````"`````````#,3P```````%B@(```````"`````````!A4```````
M`."=(```````!@````$``````````````.B=(```````!@````(`````````
M`````/"=(```````!@````,``````````````/B=(```````!@````0`````
M``````````">(```````!@````4```````````````B>(```````!@````8`
M`````````````!">(```````!@````<``````````````!B>(```````!@``
M``@``````````````"">(```````!@````D``````````````"B>(```````
M!@````H``````````````#">(```````!@````L``````````````#B>(```
M````!@````P``````````````$">(```````!@````T``````````````$B>
M(```````!@````X``````````````%">(```````!@````\`````````````
M`%B>(```````!@```!```````````````&">(```````!@```!$`````````
M`````&B>(```````!@```!(``````````````'">(```````!@```!,`````
M`````````'B>(```````!@```!0``````````````(">(```````!@```!4`
M`````````````(B>(```````!@```!8``````````````)">(```````!@``
M`!<``````````````)B>(```````!@```!@``````````````*">(```````
M!@```!D``````````````*B>(```````!@```!H``````````````+">(```
M````!@```!L``````````````,">(```````!@```!P``````````````,B>
M(```````!@```!T``````````````-">(```````!@```!X`````````````
M`-B>(```````!@```!\``````````````.">(```````!@```"``````````
M`````.B>(```````!@```"$``````````````/">(```````!@```"(`````
M`````````/B>(```````!@```",```````````````"?(```````!@```"0`
M``````````````B?(```````!@```"4``````````````!"?(```````!@``
M`"8``````````````!B?(```````!@```"<``````````````""?(```````
M!@```"@``````````````"B?(```````!@```"D``````````````#"?(```
M````!@```"H``````````````#B?(```````!@```"L``````````````$"?
M(```````!@```"P``````````````$B?(```````!@```"T`````````````
M`%"?(```````!@```"X``````````````%B?(```````!@```"\`````````
M`````&"?(```````!@```#```````````````&B?(```````!@```#$`````
M`````````'"?(```````!@```#(``````````````'B?(```````!@```#,`
M`````````````("?(```````!@```#0``````````````(B?(```````!@``
M`#4``````````````)"?(```````!@```#8``````````````)B?(```````
M!@```#<``````````````*"?(```````!@```#@``````````````*B?(```
M````!@```#D``````````````+"?(```````!@```#H``````````````+B?
M(```````!@```#L``````````````,"?(```````!@```#P`````````````
M`,B?(```````!@```#T``````````````-"?(```````!@```#X`````````
M`````-B?(```````!@```#\``````````````."?(```````!@```$``````
M`````````.B?(```````!@```$$``````````````/"?(```````!@```$(`
M`````````````/B?(```````!@```$,``````````````#"<(```````!0``
M`%<``````````````$"<(```````!0```%$``````````````&"@(```````
M!0```&```````````````&B@(```````!0```%4``````````````'"@(```
M````!0```%P``````````````%#H#04``.A%-0``6,,``````````````/\U
MBH4@`/\EC(4@``\?0`#_)8J%(`!FD/\EBH4@`&:0_R6*A2``9I#_)8J%(`!F
MD/\EBH4@`&:0_R6*A2``9I#_)8J%(`!FD/\EBH4@`&:0_R6*A2``9I#_)8J%
M(`!FD/\EBH4@`&:0_R6*A2``9I#_)8J%(`!FD/\EBH4@`&:0_R6*A2``9I#_
M)8J%(`!FD/\EBH4@`&:0_R6*A2``9I#_)8J%(`!FD/\EBH4@`&:0_R6*A2``
M9I#_)9*%(`!FD/\EDH4@`&:0_R62A2``9I#_)9*%(`!FD/\EHH4@`&:0_R6B
MA2``9I#_):*%(`!FD/\EHH4@`&:0_R6BA2``9I#_):*%(`!FD/\EHH4@`&:0
M_R6BA2``9I#_):*%(`!FD/\EHH4@`&:0_R6BA2``9I#_):*%(`!FD/\EHH4@
M`&:0_R6BA2``9I#_):*%(`!FD/\EHH4@`&:0_R6BA2``9I#_):*%(`!FD/\E
MHH4@`&:0_R6JA2``9I#_):J%(`!FD/\EJH4@`&:0_R6JA2``9I#_);J%(`!F
MD/\ENH4@`&:0_R6ZA2``9I#_);J%(`!FD/\EPH4@`&:0_R7"A2``9I#_)<*%
M(`!FD/\EPH4@`&:0_R7"A2``9I#_)<*%(`!FD/\EPH4@`&:0_R7"A2``9I#_
M)<*%(`!FD%-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`CH&?__
M_TB+-4J%(`!(BST;A2``2(GRZ$O^__^`/>2%(```=37HK?[__TB%P$B)!7.6
M(`!U"K\!````Z/?^__](B<?H'____XL]R84@`.A4____QH#1"````(L]MX4@
M`.A"____@(BJ!````HL]I84@`.@P____@(BJ!````8M$)!R->`5(N/______
M__\?2&/_2#G'=A5(C35)@2``2(T]\3(``#'`Z(O]__](P><#2(T=2S4``.B;
M_O__2(M\)!!(B07'E2``,<G'!<.5(``$````2(L72(E8"$B-'2,U``!(B5@8
M2(D02(L5#X4@`$B)4!"+5"0<2/_!.<I^$4R+!,^-<01(8_9,B43P^.OHC4H$
M2(L]C94@`$B--3,>``"#P@-%,<!(8\E(QT3(^`````!(B<'H;/W__X7`B<-U
M#DB+/5^5(`#H^OW__XG#2(L]494@`.BD_?__2(T]@C(``#'`Z)<9``!(A<!U
M+DB#/2F5(```=1-(C3T:,@``Z'P9``!(B044E2``2(L]#94@`$B%_W0%Z#(Q
M``!(BST$E2``Z!?^___H6OS__TB#Q"")V%O#2#'M2(GG2(TU/8`@`$B#Y/#H
M`````$B#[`A(C5<(2(LW3(T%9S$``$B+#7N"(`!%,<E(C3WQ_?__Z!3]__](
MC3T-A"``2(T%#80@`%5(*?A(B>5(@_@.=@](BP5"@B``2(7`=`-=_^!=PTB-
M/>&#(`!(C37:@R``N0(```!52"G^2,'^`TB)Y4B)\$B92/?Y2(7`=!)(B<9(
MBP6K@B``2(7`=`-=_^!=PX`]PH,@``!U>DB#/6""(```54B)Y4%44W0,2(L]
M*(,@`.BC_/__2(T%-'\@`$B-'35_(`!(*<-)B<1(P?L#2/_+2(L%B8,@`$@Y
MPW802/_`2(D%>H,@`$'_%,3KY.@S____2(,]!X$@``!T#$B-/<9P``#H:?O_
M_UM!7%W&!4:#(``!PTB#/>V!(```54B)Y7032(TU4(,@`$B-/9EP``#H+/S_
M_TB-/<5^(`!(@S\`=`Y(BP48@2``2(7`=`+_T%WI^_[__T%7059,C4\X055!
M5#'V55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B-3"0(08L$,4V+!#$/
MR$R)PHG`2,'J($B)!'%,B<!)P>@X2,'H*"4`_P``3`G`28G02,'B"$G!X!B!
MX@``_P!%B<!,"<!("=!(B41Q"$B#Q@A(@_Y`=:U,C5EH3(U10$R-21!,C8&`
M````,=))BP0323,$$DDS!!%(,P012(TT`$C!Z!\)\$F)!!!(@\((2('Z``(`
M`'753(L/2(M?($R+1PA,BU<03(M?&$B+3"003(G.3(G(38G/2,'H&TC!Y@5-
MB<1("<9(BT0D"$R)PHGV2,'J`DG!Y!Y)"=1,B=))C8P+F7F"6DB-A`.9>8):
M18GD2<'G'DPQXD@!\$R)UDPARDPQWDPQTDPAQD@!T4PQWD@!QHGP2(G"2(G%
M2,'M&TC!X@5(">J)TD@!RDR)R4C!Z0)!B=9)"<](B<%,B?5%B?](]]%(P>T;
M3"'A3"'^2`G.2(M,)!A)C8P*F7F"6D@!SDR)\4C!X05(">E(B<5(P>@"2,'E
M'HG)2`'Q2`GHB<5,B?!!B<U(]]!((>I,B>Y,(?A(P>X;2`G"2(M$)"!)C80$
MF7F"6D@!PDR)Z$C!X`5("?!,B>Z)P$CWUD@!T$R)\DG![@)(P>(>2"'N08G$
M20G62(M4)"A%B?9,(?%("?%)C;07F7F"6DR)XDC!ZAM(`?%,B>9(P>8%2`G6
M3(GJ2<'M`DC!XAZ)]DD)U4R)XD@!SD6)[4CWTD&)]TPA\DPAZ$R)^4@)T$B+
M5"0P2,'I&TB-E!69>8):2`'03(GZ2,'B!4@)RDR)^8G22/?12`'"3(G@2,'@
M'DG![`),(>E)"<1(BT0D.(G518GD3"'F2`G.28V,!IEY@EI(B>A(P>@;2`'.
M2(GI2,'A!4@)P4R)^$G![P)(P>`>B<E)"<=(B>A(`?%%B?](]]!!B<Y,(>!,
M(?I,B?9("<)(BT0D0$C![AM)C80%F7F"6D@!PDR)\$C!X`5("?!,B?:)P$CW
MUD@!T$B)ZDC![0)(P>(>3"'^08G%2`G52(M4)$B)[4@AZ4@)\4F-M!29>8):
M3(GJ2,'J&T@!\4R)[DC!Y@5("=9,B?*)]D@!SDC!XAY)P>X"20G63(GJ08GT
M18GV2/?23(GA2"'J3"'P2,'I&T@)T$B+5"1028V4%YEY@EI(`=!,B>)(P>(%
M2`G*3(GAB=)(]]%(`<),B>A)P>T"2,'@'DPA\4&)UTD)Q4B+1"1818GM3"'N
M2`G.2(V,!9EY@EI,B?A(P>@;2`'.3(GY2,'A!4@)P4R)X$G![`)(P>`>B<E)
M"<1,B?A(`?%%B>1(]]")S4PAZ$PAXDB)[D@)PDB+1"1@2,'N&TF-A`:9>8):
M2`'"2(GH2,'@!4@)\$B)[HG`2/?62`'03(GZ2<'O`DC!XAY,(>9!B<9)"==(
MBU0D:$6)_TPA^4@)\4F-M!69>8):3(GR2,'J&T@!\4R)]DC!Y@5("=9(B>I(
MP>T"2,'B'HGV2`G53(GR2`'.B>U(]])!B?5,(?I((>A,B>E("=!(BU0D<$C!
MZ1M)C904F7F"6D@!T$R)ZDC!X@5("<I,B>F)TDCWT4@!PDR)\$G![@)(P>`>
M2"'I08G420G&2(M$)'A%B?9,(?9("<Y)C8P'F7F"6DR)X$C!Z!M(`<Y,B>%(
MP>$%2`G!3(GH2<'M`DC!X!Z)R4D)Q4R)X$@!\46)[4CWT$&)STPA\$PAZDR)
M_D@)PDB+A"2`````2,'N&TB-A`69>8):2`'"3(GX2,'@!4@)\$R)_HG`2/?6
M2`'03(GB2<'L`DC!XAY,(>Z)Q4D)U$B+E"2(````18GD3"'A2`GQ28VT%IEY
M@EI(B>I-B?Y(P>H;2<'O`D@!\4B)[DG!YAY(P>8%30GW2`G62(GJ18G^2/?2
M3"'PB?9,(>)(`<Y)B>]("=!(BY0DD````(GQ28V4%9EY@EI)B<U(`=!(B<I(
MP>(%2<'M&TG!YQY,">I(P>T"3`G]B=)!B>](`<)(B<U(BX0DF````$CWU4PA
M_DPA]4&)U4@)[DF-K`29>8):3(GH2,'H&T@![DR)[4C!Y05("<5(B<A(P>D"
M2,'@'HGM2`G!3(GH2`'U2/?0B<Y!B>Q,(?A((?)("<)(BX0DH````$F-A`:9
M>8):38GF2<'N&T@!PDR)X$C!X`5,"?")P$@!T$R)ZDG![0)(P>(>08G&20G5
M2(N4)*@```!,,>DQS4F-E!>AZ]EN2(U,%0!,B?),B?5(P>T;2,'B!4@)ZHG2
M2`'*3(GA2<'L`DC!X1Z)U4P)X4V)[$6)[4DQS$P#K"2X````1#'@3(ND)+``
M``!*C;0FH>O9;DF)[$G![!M(`?!(B>Y(P>8%3`GF38GT2<'N`DG!Y!Z)]DT)
M]$F)SD@!\$TQYHG&B<E$,?))B?9(`XPDP````$V-K!6AZ]EN2(GR2<'N&TC!
MX@5,"?*)TDV-=!4`2(GJ2,'M`DC!XAY(">I,B>5%B?5(,=5%B>0QZ$B-K`&A
MZ]EN3(GH3(GI2,'I&TC!X`5("<B)P$B-3`4`2(GU2,'N`DC!Y1Y("?5,`Z0D
MR````$B)UD@Q[HG(B=)!,?9(B<9(`Y0DT````$C!Y@5/C:0TH>O9;DF)QDG!
M[AM,"?:)]DV--#1,B>Y)P>T"2,'F'DP)[DF)[46)]$DQ]8GM2`.L)-@```!$
M,>E-B>5(C8P*H>O9;DR)XDG![1M(P>(%3`GJB=)(`<I(B<%(P>@"2,'A'D&)
MU4@)P4B)\(GV2#'(2`.T).````!!,<9,B>A.C;0UH>O9;DR)[4C!X`5(P>T;
M2`GHB<!)C2P&3(G@2<'L`DC!X!Y,">!)B<Q!B>Y),<2)R40QXDR-I!:AZ]EN
M3(GR3(GV2,'B!4C![AM(`XPDZ````$@)\HG228TT%$R)ZDG![0)(P>(>3`GJ
M28G%08GT23'5B<!(`X0D\````$0Q[4V)Y4B-K"FAZ]EN3(GA2<'M&TC!X05,
M">F)R4@!Z4R)]4G![@)(P>4>08G-3`GU28G6B=)),>Y(`Y0D^````$0Q]DV)
M[DB-M#"AZ]EN3(GH2<'N&TC!X`5,"?")P$@!\$R)YDG![`)(P>8>08G&3`GF
M28GLB>U),?1$,>%-B?1(C8P*H>O9;DR)\DG![!M(P>(%3`GBB=)(`<I,B>E(
M`ZPD``$``$G![0)(P>$>08G43`GI28GUB?9),<U(`[0D"`$``$0QZ$R-K`6A
MZ]EN3(G@3(GE2,'M&TC!X`5(">B)P$F-;`4`3(GP2<'N`DC!X!Y,"?!)B<Y!
MB>U),<:)R4@#C"00`0``1#'R3(VT%J'KV6Y,B>I,B>Y(P>X;2,'B!4@)\HG2
M28TT%DR)XDG![`)(P>(>3`GB28G$08GV23'4B<!$,>5-B?1(C:PIH>O9;DR)
M\4G![!M(P>$%3`GAB<E(`>E,B>U)P>T"2,'E'D&)S$P)[4@#A"08`0``28G5
M23'MB=)(`Y0D(`$``$0Q[DV)Y4G![1M(C;0PH>O9;DR)X$C!X`5,">B)P$@!
M\$R)]DG![@)(P>8>08G%3`GV28GNB>U),?9(`ZPD*`$``$0Q\4V)[DB-C`JA
MZ]EN3(GJ2<'N&TC!X@5,"?*)TD@!RDR)X4G![`)(P>$>08G63`GA28GTB?9)
M,<Q(`[0D,`$``$V)]T0QX$R-I`6AZ]EN3(GP3(GU2,'M&TC!X`5(">B)P$F-
M+`1,B>A)P>T"2,'@'DP)Z$F)S4&)[$DQQ8G)1#'J38GE2(VT%J'KV6Y,B>)(
MP>(%2<'M&T@#C"0X`0``3`GJ2<'N`DG!YQZ)TDT)]TV)YDR-+!9(B<9)P>P"
M3#'^2<'F'HG`1(GJ,?5(`X0D0`$``$B-M"FAZ]EN2(G12(G52,'M&TC!X05-
M">9(">E,B?U%B?],,?6)R4$Q[4@!\8G.3HVD**'KV6Y)B=5(B?!(P>H"2(GU
M2<'E'DC![1M(P>`%20G53(GR2`GH3`GJB<!((=%,B?))C2P$3"'JN-R\&X]%
MB?8)T4B)PD@#E"1(`0``08GL3`'Z38GG2`'13(GB2,'B!4G![QM,"?J)TD@!
MRDB)\4C![@)(P>$>08G72`GQ3(GN2`G.2"'U3(GN18GM2"'."?5(B<9(`[0D
M4`$``$D!]DR)_DD![DR)_4C!Y@5(P>T;2`GNB?9)C2PV3(GF2<'L`DC!YAY,
M">9)B<Q!B>Y)"?1,(>))B<R)R4DA]$0)XDF)Q$P#I"18`0``30'L38GU3`'B
M38GT2<'E!4G![!M-">5%B>U.C20J3(GZ2<'O`DC!XAY,"?I)B?=%B>5)"==,
M(?U)B?>)]DDAUT0)_4F)QTP#O"1@`0``20'/3(GI3`']38GO2,'A!4G![QM,
M"?F)R4R-?`T`3(GQ2<'N`DC!X1Y,"?%)B=9$B?U)"<Y-(?1)B=:)TDDASD4)
M]$F)QDP#M"1H`0``20'V2(GN30'T28GN2,'F!4G![AM,"?:)]DV--#1-B>Q)
MP>T"2<'D'DT)[$F)S42)]DT)Y4TA[TF)S8G)32'E10GO28G%3`.L)'`!``!)
M`=5(B?)-`>])B?5(P>(%2<'M&TP)ZHG238TL%TB)ZDC![0)(P>(>2`G53(GB
M18GO2`GJ22'63(GB18GD2"'J00G62(G"2`.4)'@!``!(`=%,B?I,`?%-B?Y(
MP>(%2<'N&TP)\HG23(TT$4B)\4C![@)(P>$>2`G.2(GI1(GR2`GQ22'-2(GI
MB>U((?%!"<U(B<%(`XPD@`$``$D!S$B)T4T![$F)U4C!X05)P>T;3`GIB<E-
MC2P,3(GY2,'A'DG![P),"?E)B?=%B>Q)"<]-(?Y)B?>)]DDAST4)_DF)QTP#
MO"2(`0``20'O3(GE30'^38GG2,'E!4G![QM,"?V)[4V-/"Y(B=5(P>H"2,'E
M'D@)ZDB)S46)_D@)U4DA[4B)S8G)2"'500GM2(G%2`.L))`!``!(`>Y,B?5,
M`>Y-B?5(P>4%2<'M&TP)[8GM3(TL+DR)YDG![`)(P>8>20GT2(G61(GM3`GF
M22'W2(G6B=),(>9!"?=(B<9(`[0DF`$``$@!\4B)[DP!^4F)[TC!Y@5)P>\;
M3`G^B?9,C3PQ3(GV2<'N`DC!YAY,"?9-B>9$B?E)"?9-(?5-B>9%B>1)(?9%
M"?5)B<9,`[0DH`$``$D!UDB)RDT!]4F)SDC!X@5)P>X;3`GRB=)-C705`$B)
MZDC![0)(P>(>2`G52(GR18GU2`GJ22'72(GRB?9((>I!"==(B<)(`Y0DJ`$`
M`$D!U$R)ZDT!_$V)[TC!X@5)P>\;3`GZB=)-C3P428G,2<'D'DC!Z0),">%)
MB>Q$B?I)"<Q-(>9)B>R)[4DAS$4)YDF)Q$P#I"2P`0``3`'F28G43`'V28G6
M2<'D!4G![AM-"?1%B>1.C30F3(GN2<'M`DC!YAY)"?5(B<Y%B?1,">Y)(?=(
MB<Z)R4PA[D$)]TB)QD@#M"2X`0``2`'U3(GF3`']38GG2,'F!4G![QM,"?Z)
M]DR-?#4`2(G62,'J`DC!YAY("=9,B>I$B?U("?))(=9,B>I%B>U((?)!"=9(
MB<)(`Y0DP`$``$@!RDB)Z4D!UDB)ZDC!X05(P>H;2`G1B<E)C10.3(GA2<'L
M`DC!X1Y)"<Q(B?%!B=9,">%)(<](B?&)]DPAX4$)STB)P4@#C"3(`0``20'-
M3(GQ30']38GW2,'A!4G![QM,"?F)R4V-?`T`28GM2,'M`DG!Y1Y,">U-B>5$
MB?E)">U,(>I-B>5%B>1)(>U$">I)B<5,`ZPDT`$``$P![DF)S4@!UDB)RDG!
MY05(P>H;20G518GM2HT4+DR)]DG![@)(P>8>20GV2(GN08G53`GV22'W2(GN
M3"'V00GW2(G&2`.T)-@!``!(`X0DX`$``$D!]$R)[DT!_$V)[TC!Y@5)P>\;
M3`G^B?9-C3PT2(G.2,'I`DC!YAY("<Y,B?%%B?Q("?%((<I,B?%%B?9((?$)
MRHGI2`'!3(G@2`'*3(GA2,'H&TC!X05("<%,B>A)P>T"B<E(P>`>2`'1NM;!
M8LI,">A)B=5,`ZPDZ`$``(G-30'N28GUB?9),<5%,>])B>U-`?=)B>Y)P>4%
M2<'N&TT)]4V)YDG![`))P>8>18GM30GF28G43`.D)/`!``!-`?U%B>],`>9)
MB<2)P$TQ]$0QX4V)_$@!\4R)_DG![!M(P>8%3`GF28GL2,'M`DG!Y!Z)]DD)
M[$B)U4@#K"3X`0``2`'QB<Y(`>A,B?5%B?9,,>5!,>U(B?5)`<5(B?!(P>4%
M2,'H&T@)Q8GM3`'M38G]2<'E'DG![P*)Z$T)_4F)UTP#O"0``@``30'^38GG
M18GD33'O1#'Y28G'3`'Q28G&2<'O&TG!Y@5-"?Y)B?=(P>X"2<'G'D6)]DD)
M]TB)UD@#M"0(`@``20'.1(GQ20'T3(GN18GM3#'^,?5(B<Y,`>5)B<Q(P>8%
M2<'L&TP)YHGV2`'N2(G%2,'H`DC!Y1Y!B?1("<5(B=!(`X0D$`(``$D!Q4R)
M^$6)_T@QZ$$QQDR)X$T![DV)Y4C!X`5)P>T;3`GHB<!,`?!)B<Y(P>D"2<'F
M'D&)Q4P)\4F)UDP#M"08`@``30'W28GNB>U),<Y$,?9-B>Y,`?Y-B>])P>X;
M2<'G!4T)]T6)_TD!]TR)YDG![`)(P>8>18G^20GT2(G62`.T)"`"``!(`?5(
MB<Z)R4PQYC'P3(GV2`'H3(GU2,'N&TC!Y05("?5,B>Y)P>T"2,'F'HGM3`GN
M28G53`.L)"@"``!(`<6)Z$P!Z4V)Y46)Y$DQ]44Q[TF)Q4D!STB)P4G!Y05(
MP>D;20G-18GM30']38GW2<'N`DG!YQY$B>E-"?Y)B==,`[PD,`(``$T!_$F)
M]XGV33'W1#']28G/3`'E28G,2<'O&TG!Y`5-"?Q%B>1)`>Q(B<5(P>@"2,'E
M'D6)YT@)Z$B)U4@#K"0X`@``2`'N3(GU18GV2#'%03'M3(G]20'U3(G^2,'M
M&TC!Y@5(">Y(B<V)]DP![DC!Y1Y(P>D"2`G-2(G12`.,)$`"``!!B?5)`<Y(
MB<&)P$@QZ4$QS$R)Z4T!]$V)[DC!X05)P>X;3`GQB<E,`>%-B?Q)P>\"2<'D
M'D&)SDT)YTF)U$P#I"1(`@``3`'@28GLB>U-,?Q$,>9-B?1(`<9,B?!)P>P;
M2,'@!4P)X(G`2`'P3(GN2<'M`DC!YAY!B<1)"?5(B=9(`[0D4`(``$@!]4R)
M_D6)_TPQ[C'Q3(GF2`'I3(GE2,'E!4C![AM("?6)[4@!S4R)\4G![@)(P>$>
MB>Y)"<Y(B=%(`XPD6`(``$D!STR)Z46)[4PQ\3'(2(GQ3`'X28GW2,'I&TG!
MYP5)"<],B>%)P>P"2,'A'D6)_TP)X4F)U$P#I"1@`@``20''1(GX30'E38GT
M18GV23',1#'E28G$3`'M28G%2<'D!4G![1M-">Q)B?5(P>X"2<'E'D6)Y$D)
M]4B)UD@#M"1H`@``20'L1(GE20'V2(G.B<E,,>Y!,?=(B>Y-`?=)B>Y(P>8%
M2<'N&TP)]DF)QDC!Z`))P>8>B?9)"<9(B=!(`X0D<`(``$P!_D&)]T@!P4R)
MZ$6)[4PQ\$$QQ$R)^$D!S$R)^4C!Z!M(P>$%2`G!B<E,`>%)B>Q(P>T"2<'D
M'HG(3`GE28G43`.D)'@"``!-`>5-B?1),>Q$,>9)B<1)`?5(B<9)P>P;2,'F
M!4P)YDF)Q$$!]4R)_DC!YAY(`Y0D@`(``$C!Z`))P>0>2<'O`D4!Z$D)Q$2)
M\$P)_D4!XD$!\P'K2`'"2(GH3(E'"$@Q\$R)5Q!,B5\8,<%(B5\@2(T$"DR)
MZDR)Z4C!X@5(P>D;2`G*`=!!`<%(BX0DB`(``&1(,P0E*````$R)#W0%Z&KE
M__](@<28`@``6UU!7$%=05Y!7\-!5T%6055!5%53,>U(@^P(2(7_=&5,BS5\
M:R``2(GZ387V=%:*`H3`=`D\/70%2/_"Z_$I^DF)]TF)_4V)]$ACVDF++"1(
MA>UT,$B)VDR)[DB)[^C0X___A<!U&(!\'0`]=1%-*?1(C6P=`4G!_`-%B2?K
M!DF#Q`CKQUI(B>A;74%<05U!7D%?PTB#[!AD2(L$)2@```!(B40D"#'`2(UT
M)`3H6?___TB+5"0(9$@S%"4H````=`7HG.3__TB#Q!C#55-(B?M(@^P89$B+
M!"4H````2(E$)`@QP$B-;"0$,<!(B>Y(B=_H%/___TB%P'0B2&-4)`1(BP6;
M:B``2(T$T$B+4`A(A=)(B1!TTDB#P`CK[DB+1"0(9$@S!"4H````=`7H,.3_
M_TB#Q!A;7<-!5D%505152(G]4TB)\TB#[!!D2(L$)2@```!(B40D"#'`,<"`
M/CU(C70D!`^4P$F#SO]%,>U(`<-,B?%$B.A(B=_RKDB)[TCWT4Z-)#'H?O[_
M_TB%P'0V2(G'2(G"3(GQ1(CH\JY)B<U)]]5-`?5-.>P/AZT````QP(H,`X@,
M`DC_P(3)=?,QP.D4`0``3(LUU&D@`#'`08G%2/_`28-\QO@`=?*#/35Z(```
M08UU`G0C2&/V3(GW2,'F`^BHX?__2(7`2(D%GFD@`'5`@\C_Z<T```!(8_;'
M!?]Y(``!````2(T\]0````#H^N'__TB%P'3926/53(GV2(G'2,'B`^CKX?__
M2(D%7&D@`$B+!55I(`!)8]5(QT30"`````!$B6PD!$B)Z(H0A-)T"H#Z/70%
M2/_`Z_!(8TPD!$B+%25I(`!(*>A(F$F-?`0"3(TLRNB2X?__2(7`28E%``^$
M:?___TAC5"0$2(L%^6@@`$B+!-!(_\6*5?^$TH@0=`J`^CUT!4C_P.OJQ@`]
M,=**#!.(3!`!2/_"A,EU\NGE_O__2(M<)`AD2#,<)2@```!T!>ARXO__2(/$
M$%M=05Q!74%>PT%6055!5%532('LH````&1(BP0E*````$B)A"28````,<!(
MA?\/A.\```"`/P!(B?T/A.,```#H4>#__TB%P$F)Q$R-;"0(#X3-````3(GG
MZ*#@__](A<`/A*P```!(C5@32(TU?14``$B)W^A\X/__A<!TV$B--6D5``!(
MB=_H:>#__X7`=,5(@\[_,<!(B>](B?'RKDB)WTB)RDB)\?*N2/?22(G(2/?0
MC3P02&/_Z'#@__](C34L%0``28G&2(G'2(G92(GJ,<#H=N'__TR)]TR)[NA+
MX?___\!,B?=T%XM$)"`E`/```#T`0```=0?H"O___^L%Z"#@__],B??H&.'_
M_^E#____3(GGZ#O@__](B>_HZ^#__TB+A"28````9$@S!"4H````=`7H,^'_
M_TB!Q*````!;74%<05U!7L-32(G[BSUA9R``Z.S@__](C;```@``2(G?Z.7?
M__^%P'0$,<#K4XL]/V<@`.C*X/__BX`8`@``)0#P```]`$```'47O@(```!(
MB=_H(]___X7`#Y3`#[;`ZQ^+/0MG(`#HEN#__XN`&`(``"4`\```/0"@``!U
MJ^O*6\-(@^P(BSWF9B``Z''@__](BQ7J92``2(G'2(T-(%,``%A(C34)%```
MZ4/@__](@^P(BSVY9B``Z$3@__](B<?HO/___XL]IF8@`.@QX/__2(G'3(T%
M@18``$B-%?P/``!82(TUY1,``$4QR4R)P>F5WO__05154TB![!`@``!(C6PD
M!F1(BP0E*````$B)A"0((```,<#HC=[__TR-!<`3``!(C16]$P``B<&^`1``
M`#'`2(GOZ$;>__^#^/]U!S')Z8$```!(8]!(@?H`$```=@(/"X7`>.=(C9PD
M!Q```+H`$```2(GO2(G>Z/C>__^%P$F)Q'C(C7@!2&/_Z&;>__](A<!(B<%T
MM4@YV$EC[',)2(T$*$@YPW*W2#G9=@E(C00K2#G!<JE!@?P!$```?Z!(B<](
MB>I(B=[H4-___TB)P<8$*`!(B[0D""```&1(,S0E*````$B)R'0%Z$;?__](
M@<00(```6UU!7,/I`/___T%6055!5%5(B?U32(T][1(``$B)\TB![!`0``!D
M2(L$)2@```!(B80D"!```#'`Z#+Z__^^+P```$B)[TF)Q>@)WO__2(7`=!9(
MC3VX$@``2(GN,<#HLOK__^DV`0``,<!(B>](@\G_\JY(C36D$@``2(G?3(UD
M)`A(]]%$C7'_Z(#>__](B<-(A=MTO(`[`$B-!1\2``!(#T38387M=!-(B=Y,
MB>_H$MW__X7`#X3,````,<!(@\G_2(G?\JY(]]&-0?](8]"`?!/_+W4+_\A(
M8]#&!!,`Z^M"C40P`3W_#P``#X]@____3(T%)Q(``$B-%0T3```QP$F)Z4B)
MV;X`$```3(GGZ('<____P#T`$```=@(/"XL]8&0@`.CKW?__2(VP``(``$R)
MY^C$W?__A<!U2HL]0F0@`.C-W?__BX`8`@``)0#P```]`(```'4MO@$```!,
MB>?H)MS__X7`=1Q(C3V>$0``3(GFZ)KY__],B>?HJ]S__TB)Q>L62(TUCQ$`
M`#'_Z'C=__](B</I\_[__TB+E"0($```9$@S%"4H````2(GH=`7HA=W__TB!
MQ!`0``!;74%<05U!7L-(C5<!2(GXBDK_A,ET#(#Y+T@/1,)(_\+K[<-(A?]T
M2T2*!TB)_D6$P'1`,<!(@\G_\JY(]]%(C50._D@YUG,9@#HO=0U(_\KK\4C_
MRD@YUG,'@#HO=?/K(T@YUG4>08#X+TB-/>X0``!U!TB-/800``#I[MO__X`Z
M+W4(2/_*2#G6<O-(*?)(C4("2#T`$```=R=(_\)(@?H`$```=@(/"TB-/85C
M(`!(@^P(Z`S<__](C05U8R``6L,QP,-32(TU($\``+DB````2(/L,&1(BP0E
M*````$B)1"0H,<!(C7PD!DB-7"0&\Z1(C3UH$```Z.CW__](C3UE$```,<#H
MVO?__TB-/5\0```QP.C,]___2(T]6A```#'`Z+[W__](C3U3$```,<#HL/?_
M_TB-/540```QP.BB]___2(T]_`\``#'`Z)3W__](C3U%$```,<#HAO?__TB-
M/4$0```QP.AX]___2(T]/1```#'`Z&KW__](C3W-#P``,<#H7/?__TB-/2L0
M```QP.@6]___2(7`=!%(C3T$$```2(G&,<#HIO?__TB-/1@0```QP.CR]O__
M2(7`=!%(C3T7$```2(G&,<#H@O?__TB-/1$0```QP.C.]O__2(7`2(G&2(T]
M6@\``'4=2(T]!!```#'`Z+'V__](A<!T#DB-/94/``!(B<8QP.LD2(U[$4B-
M-?`/``"Z"@```.@HVO__A<!U$$B-<QM(C3UJ#P``Z!OW__](C34,$0``2(T]
M.P\``#'`Z`;W__](BT0D*&1(,P0E*````'0%Z!K;__](@\0P6\.#/35A(`#_
M=3A(C3TE#P``2(/L"#'`Z"KV__\QTDB%P'0.B@"$P`^5PCPP#Y7`(<(/MM*)
M%0-A(`"+!?U@(`!:PXL%]6`@`,-(@^P(Z,O:__^)Q^CDV?__,=)(A<!T`TB+
M$$B)T%K#05152(G]4TB-/3@/```QP.C)]?__2(7`2(GN=&*`.`!(B<-T6DB)
MQ^B`V?__2(7`=5](@\[_2(GO2(GQ\JY(B=](B<I(B?'RKDCWTDB)R$CWT$B-
M/`+H$MG__TB--1H/``!(C0TD#@``28G$2(G'28G82(GJ,<#H$=K__TR)YEM=
M05Q(C3V\#@``,<#I\_7__UM=05S#05=!5DB--01@(`!!54%428G]55.Y#```
M`$B![$B!``!D2(L$)2@```!(B80D.($``#'`2(T%C0X``$B-?"1(2,=$)"@`
M````\Z5(B40D&$B-!4(-``!(C3V$#0``2,=$)$``````2(E$)"!(C05:#@``
M2(E$)#!(C053#@``2(E$)#@QP.B^]/__2(7`=""`.`!(B<-T&$B)Q^C+_O__
M2(G?Z&#8__](B<7I[P@``#'`2(UL)##HD/[__TB%P$B)PW4Y2(M]`$B%_W0I
M,<`QV^AS]/__2(7`=!"`.`!T"TB)Q^@@V/__2(G#2(/%"$B%VW30ZP=(C1W$
M#0``,<!(B=](@\G_\JY,C37,#0``2/?12(U\"?_HO-?__TB)Q4F)Q(`[`'09
M#[833(GG3(GV,<!(_\-)@\0"Z+K8___KXDR-9"1(28L<)$B%VW0N2(G?,<#H
M\?/__TB%P$B)PW0C@#@`=!Y(B<?HB/?__X7`=!)(B=_HC]?__TB)PTR-="08
MZS!)@\0(Z[Q-BR9-A>1T)T&`/"0`="!,B>?H5??__X7`=`M,B>?H7-?__TB)
MPTF#Q@A(A=MTT4B#SO\QP$B)WTB)\?*N2(GO2/?12(G*2(GQ\JY(B<A(]]!$
MC;P0`@0``$UC_TR)_^CKUO__3(T%[`P``$B-#?\+``!(C37C#```2(G'28G$
M28GI2(G:,<#HX]?__[[``0``3(GGZ*;7____P'4SZ)77__^#.!%T*>B+U___
M28M5`$2+`$B--:L,``!(BSW662``3(GA,<#H--?__^E$!P``BST!7B``Z(S7
M__](C;```@``3(GGZ(76__^%P$&)Q@^%`P<``(L]W%T@`.AGU___BX`8`@``
M)0#P```]`$````^%X@8``(L]NUT@`.A&U___BY@<`@``Z&O7__\YPP^%Q`8`
M`(L]G5T@`.@HU___BX`8`@``)?\!```]P`$```^%HP8``$R)_^CRU?__2(T]
MSPL``$B)Q3'`Z%+R__](A<!T'$B)Q^@$UO__28M]`$B)QNC3]___2(7`28G'
M=01-BWT`,<!(@\G_3(G_\JY(]]%(C5G_@_L#?F-(8\-(C37L"P``28U\!_SH
M6=7__X7`=4N#^P1T#H/K!$ACVT&`?!__+W4X28M="$B%VW0O,<!(@\G_2(G?
M\JY(]]%(C4'_2(/X`W872(U\"_M(C36C"P``Z!#5__^%P$P/1/LQP.AG^___
MA<`/A28%```Q]DR)_^AAU?__A<!!B<</A!$%``!,C:PD.`$``+H"````2,?&
M[O___XG'Z+O4__^Z!@```$R)[D2)_^C#U?__@+PD.`$```!U98"\)#D!``!#
M=5N`O"0Z`0``0751@+PD.P$``$-U1X"\)#P!``!(=3V`O"0]`0``174SN@(`
M``!(Q\;&____1(G_Z%O4__^Z*0```$R)[D2)_^ACU?__3(T-_@L``$V)Z.E7
M!```,=(Q]D2)_^@PU/__N(FKS>](C5PD>$C'1"1X`2-%9TB)A"2`````N/[<
MNIA(QX0DD````'94,A!(B80DB````+CPX=+#2,>$)*``````````2(F$))@`
M``!(QX0DJ`````````#'A"3P`````````+H`@```3(GN1(G_Z-34__^%P$F)
MP$&)Q@^.?@$``$B+C"2@````26/`C13!2#G1=@A(_X0DJ````$C!Z!U(`80D
MJ````$ACA"3P````2(F4)*````"%P`^$EP```$&^0````$B-?`,X02G&13GP
M10].\$PY[TECSG,)2(T$#TDYQ7(/3#GO=@Q)C40-`$@YQW,"#PM(@?D`@```
M3(E$)`AW\$B)RDR)[DB)#"3HB]3__XN$)/````!(BPPD3(M$)`A$`?"#^$")
MA"3P````#X4L____28UT#0!$B<!(B=]$*?!(B30D08G&Z+O7__](BS0DZP-,
MB>Y(C4LX08/^/WY-2#G.=@E(C4-X2#G&<H-(.<Y,C49`<PE,.<$/@G'___](
MB<^Z0````$B)3"0(3(D$)$&#[D#H`=3__TB)W^AFU___2(M,)`A(BS0DZZU(
MC4,X26/62#G&=@Q(`=!(.<8/@BS___](C4,X2#G&<PU(C0P62#G(#X(6____
M2(/Z2`^'#/___TB->SCHK=/__T2)M"3P````Z63^__]$B?_H,-/__TR+M"2@
M````3(NL)*@```!,B?!(P>@#@^`_C4@!2)C&A`2P````@(/Y.$AC^7XL3(U[
M.+I`````,?8IRDACTDP!_^@1TO__2(G?Z+;6__^Z.````#'V3(G_ZQ&Z.```
M`$B-?#LX,?8IRDACTNCGT?__3(GH2(G?1(BL).L```!(P>@81(BT).\````Q
MVXB$).@```!,B>A(P>@0B(0DZ0```$R)Z$R-K"3[````2,'H"(B$).H```!,
MB?!(P>@8B(0D[````$R)\$C!Z!"(A"3M````3(GP2,'H"(B$).X```#H'M;_
M_TB+1"1X3(V$)`\!``!(B<*(A"3^````2,'J&(B4)/L```!(B<)(P>H0B)0D
M_````$B)PDB+A"2`````2,'J"(B4)/T```!(B<*(A"0"`0``2,'J&(B4)/\`
M``!(B<)(P>H0B)0D``$``$B)PDB+A"2(````2,'J"(B4)`$!``!(B<*(A"0&
M`0``2,'J&(B4)`,!``!(B<)(P>H0B)0D!`$``$B)PDB+A"20````2,'J"(B4
M)`4!``!(B<*(A"0*`0``2,'J&(B4)`<!``!(B<)(P>H0B)0D"`$``$B)PDB+
MA"28````2,'J"(B4)`D!``!(B<*(A"0.`0``2,'J&(B4)`L!``!(B<)(P>H0
MB)0D#`$``$B)PDC!Z@B(E"0-`0``0@^V%"M(C3P;2(TU6@8``#'`2/_#3(D$
M)$P!Q^AFT?__2(/[%$R+!"1UU4R-#:<'``#&A"0W`0```$B-#4@%``!(C35Z
M!@``3(GB2(GO,<#H,M'__^F3````2(TU%0<``$B-/6`%```QP$B-'6@'``#H
M".W__^BLS___3(T-5P<``$B-#0`%``!(C35!!@``08G`3(GB2(GO,<#HY]#_
M_[[``0``2(GOZ*K0____P'4\Z)G0__^#.!%U,NAGS___2(/L"$'_QDB-#;L$
M``!32(TU"08``$&)P$R)XD6)\4B)[S'`Z)[0__]86NNS3(GGZ&K0__](C3UU
M!```2(GN,<#H>.S__TB)[^CL]?__ZQY)BU4`2(L]E%(@`$B--<X%``!,B>$Q
MP.CKS___,>U(B[0D.($``&1(,S0E*````$B)Z'0%Z%[0__](@<1(@0``6UU!
M7$%=05Y!7\-!54%455-(@^P(BSV$5B``Z`_0__^+/7E6(`!(B</H`=#__XJ`
MN````$B-/2$$``"(@[D````QP.A`Z___2(7`=`N`.#%U!H!X`0!T!S'`Z$#S
M__^+/3I6(`#HQ<___TB--8X%``"Y"P```+H!````2(G'Z.3.__](A<!U-8L]
M$58@`.B<S___2(TU:@4``+D#````N@$```!(B<?HN\[__TB%P$B)PP^%R@``
M`.D,`0``2(M`$#';3(M@*(UK`3LM3V8@`'T@BSW'52``Z%+/__\QR4ACTTR)
MYDB)Q^@*SO__2(7`=1.+!2=F(`#_R#G#=8J[`0```.M73(LH08M%#"4`!"``
M/0`$``!U!DF+11#K'8L]>U4@`.@&S___N0(````QTDR)[DB)Q^@4S___2(L-
MU64@`$ACU4B)QDB+/-'HCLW__X7`=9V)Z^EK____.QV]92``#XT@____BSTQ
M52``_\/HNL[__TR)YDB)Q^@'S?__Z]I(BT`0BST352``2(LHZ)O.__](C15K
M!```2(G'2(GNZ-'-__](BT,02(L8]D,.0'06BSWF5"``Z''.__](B=Y(B<?H
M/LW__XL]T%0@`.A;SO__2(TU,`0``+D#````N@$```!(B<?H>LW__TB%P$B)
MQ0^$AP```$B-/2H"```QP.B!Z?__2(7`2(G#=!I(BT40BSV&5"``2(LHZ`[.
M__](B=I(B>[K3^CT[?__2(7`2(G#BSUE5"``2(M%$'0@2(LHZ.?-__](B=I(
MB<=(B>[H(<W__TB)W^BQS?__ZR!(BQ6P9"``2(L82(LJZ+W-__](B=Y(B>I(
MB<?H]\S__XL]&50@`.BDS?__2(TU>P,``+H!````2(G'Z`#,__^+/?I3(`!(
MB</H@LW__TB-%6X#``!(B=Y(B<?HN,S__XL]VE,@`.AES?__2(T]4`$``,:`
MN0`````QP.BIZ/__2(7`2(D%/F0@`'4D2(L])60@`.A)\___2(7`2(D%)F0@
M`'4,2(T]'@,``.BPR___2(L]$60@`+[``0``Z.?,__^-4`&#^@%V)H/X$70A
MB<%(BP7A8R``2(L5ZF,@`$B-/04#``!(BS`QP.AQR___6%M=05Q!7<-54TB)
M^TB#[`CHF>___TB)Q^AV[___2(G%,<#HS?'__X7`="E(A=MT)(`[`'0?2(TU
ME`$``$B)[^C$R___2#G%=0M:2(G?6UWI3^K__UA;7<-52(GE4TB-'8Q.(`!(
M@^P(2(/K"$B+`TB#^/]T!/_0Z^]86UW#4.@4S___6,,````N+@`E<R\E<P!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`
M4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M<`!54T52`%5315).04U%`"4P
M,G@`<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!414U01$E2`%1-
M4`!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#0Q`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$[
M"G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I
M>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L
M("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N
M86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I
M;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\
M?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD
M;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T
M("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(
M+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D
M+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U
M9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG
M="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N
M=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N
M=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M
M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK
M*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM
M;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E
M;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@
M*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F
M:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2![
M"G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN
M8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I
M=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O
M7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT
M.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@
M;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&
M24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]
M(")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H
M+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@
M)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2([
M"F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D
M14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I
M9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*
M?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q
M=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O
M;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE
M("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT[
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,````!
M&P,[R````!@```!TB___Y````(2+__\,`0``;(W__PP%``"QD/__)`$```2H
M__]T`0``C:C__[P!``#%J/__U`$``#.I___\`0``]ZK__T0"```YK/__C`(`
M`+2L__^L`@``X:S__\0"```GK?__W`(``"*N__\4`P``)Z[__RP#``#GK___
M=`,```*P__^,`P``I+#__Z0#``!(LO__S`,``)"R___D`P``K[+___P#``!%
ML___-`0``!"]__^4!```6\#__]0$```4``````````%Z4@`!>!`!&PP'")`!
M```D````'````(B*__\0``````X01@X82@\+=PB``#\:.RHS)"(`````%```
M`$0```!PBO__Z`$`````````````3````%P```"%C___4Q<```!"#A"/`D(.
M&(X#1@X@C01"#BB,!4,.,(8&00XX@P='#M`%`S$7#CA!#C!!#BA"#B!"#AA"
M#A!"#@@```````!$````K````(BF__^)`````$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T8.0`)K#CA$#C!!#BA"#B!"#AA"#A!"#@@4````]```
M`,FF__\X`````$0.(',."``D````#`$``.FF__]N`````$$.$(8"00X8@P-'
M#C`"8@X800X000X(1````#0!```OI___Q`$```!"#A".`D(.&(T#0@X@C`1!
M#BB&!40.,(,&1PY``ZD!#C!!#BA!#B!"#AA"#A!"#@@`````````1````'P!
M``"KJ/__0@$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`0,J`0XP
M00XH00X@0@X80@X00@X(````````'````,0!``"EJ?__>P````!!#A"#`@)Y
M#@@````````4````Y`$```"J__\M`````$0.$%T."``4````_`$``!6J__]&
M`````$0.$'`."``T````%`(``$.J___[`````$(.$(P"00X8A@-!#B"#!$<.
ML$`"ZPX@00X800X00@X(`````````!0```!,`@``!JO__P4`````````````
M`$0```!D`@``\ZK__\`!````0@X0C@)"#AB-`T(.((P$00XHA@5$#C"#!E$.
MP"`#FP$.,$$.*$$.($(.&$(.$$(."````````!0```"L`@``:ZS__QL`````
M`````````!0```#$`@``;JS__Z(``````I$.$$T.""0```#<`@``^*S__Z0!
M````00X0@P)0#D`#D0$.$$$."``````````4````!`,``'2N__](`````%0.
M$&P."``4````'`,``*2N__\?`````$0.$%H."``T````-`,``*NN__^6````
M`$(.$(P"00X8A@-$#B"#!`)Y"@X800X00@X(3@M!#AA!#A!"#@@``%P```!L
M`P``":___\L)````0@X0CP)"#AB.`TD.((T$0@XHC`5$#C"&!D$..(,'3`Z`
M@P(#%`D.B(,"2PZ0@P);#HB#`D$.@(,"`F4..$$.,$$.*$(.($(.&$(.$$(.
M"#P```#,`P``=+C__TL#````0@X0C0)"#AB,`T$.((8$00XH@P5$#C`#.@,.
M*$$.($$.&$(.$$(."``````````T````#`0``'^[__]1`````$$.$(8"00X8
M@P-'#B!Z"@X81`X000X(10M!#AA!#A!!#@@``````"0```!$!```6(C__]8!
M````00X0@P)$#C`#S0$.$$,."```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#__________P``````````
M__________\`````````````````````````````````````````````````
M``````````````````````````$``````````0`````````!`````````-P"
M````````#P````````!K`P````````P`````````*!@````````-````````
M`)U-````````]?[_;P`````@`@````````4`````````0`P````````&````
M`````!`#````````"@````````!H!`````````L`````````&``````````5
M`````````````````````P````````#(G2````````<`````````J!``````
M```(`````````(`'````````"0`````````8`````````!@`````````````
M``````#[__]O``````$```@`````^?__;P`````(````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````6)P@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````*!@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@(```````````````````````````````````````BDX`
M``````"#3@```````,1/````````H$X```````#,3P``````````````````
M_____P````!A4````````$=#0SH@*$%L<&EN92`V+C0N,"D@-BXT+C```"YS
M:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E
M;&$N9'EN`"YI;FET`"YP;'0`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`
M+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M````````````````````````"P````$````"```````````"``````````(`
M```````9`````````````````````0```````````````````!,```#V__]O
M`@`````````@`@```````"`"````````[``````````#``````````@`````
M```````````````=````"P````(`````````$`,````````0`P```````#`)
M````````!`````$````(`````````!@`````````)0````,````"````````
M`$`,````````0`P```````!H!````````````````````0``````````````
M`````"T````$`````@````````"H$````````*@0````````@`<````````#
M``````````@`````````&``````````W`````0````8`````````*!@`````
M```H&`````````T````````````````````!````````````````````/0``
M``$````&`````````$`8````````0!@````````0````````````````````
M$``````````0`````````$(````!````!@````````!0&````````%`8````
M````Z`$```````````````````@```````````````````!+`````0````8`
M````````.!H````````X&@```````&4S```````````````````!````````
M````````````40````$````&`````````)U-````````G4T````````(````
M`````````````````0```````````````````%<````!`````@````````"H
M30```````*A-````````(C\```````````````````@`````````````````
M``!?`````0````(`````````S(P```````#,C````````,P`````````````
M```````$````````````````````;0````$````"`````````)B-````````
MF(T```````!L!```````````````````"````````````````````'<````!
M`````P`````````(G"````````B<````````$`````````````````````@`
M``````````````````!^`````0````,`````````&)P@```````8G```````
M`!`````````````````````(````````````````````A0````$````#````
M`````"B<(```````*)P````````(````````````````````"```````````
M`````````(H````!`````P`````````PG"```````#"<````````(P``````
M`````````````!````````````````````"7````!@````,`````````6)P@
M``````!8G````````'`!````````!``````````(`````````!``````````
M1@````$````#`````````,B=(```````R)T````````X`@``````````````
M````"``````````(`````````*`````!`````P``````````H"````````"@
M````````8````````````````````"````````````````````"F````"```
M``,`````````8*`@``````!@H````````*@0```````````````````@````
M````````````````JP````$````P````````````````````8*`````````:
M`````````````````````0`````````!``````````$````#````````````
M`````````````'J@````````M`````````````````````$`````````````
%````````
